# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.1.0 (2024-02-02)

### Added

* Add generic typing for `Specification` base class.
* Add python 3.12.

## 1.0.0 (2022-03-09)

### Added

* Add python 3.11.
* Add typing.

### Removed

* Remove deprecated python 3.6 and 3.7 support.

## 0.1.2 (2021-11-02)

### Fixed

* Fix pyproject links.

## 0.1.1 (2021-11-02)

### Changed

* Update documentation.

## 0.1.0 (2019-08-06)

### Added

* Specification basic implementation.
* Simple error reporting management.
